@@ -6,6 +6,7 @@ OC.L10N.register(
     "Copy link" : "Копирај линк",
     "Move" : "Премести",
     "Delete" : "Избриши",
+    "Delete selection" : "Избриши ги селектираните",
     "Select all" : "Избери се",
     "Go back" : "Назад",
     "Share folder" : "Сподели папка",
@@ -38,6 +39,7 @@ OC.L10N.register(
     "Link copied" : "Линкот е копиран",
     "Privacy" : "Приватност",
     "Failed to save settings" : "Неуспешно зачувување на параметрите",
+    "Failed to load settings" : "Неуспешно вчитување на параметрите",
     "Folder" : "Папка",
     "Save" : "Зачувај"
 },
