@@ -84,6 +84,7 @@ OC.L10N.register(
     "{folders} folders and {bookmarks} bookmarks" : "{folders} mappen en {bookmarks} bladwijzers",
     "_%n bookmark_::_%n bookmarks_" : ["%n bladwijzer","%n bladwijzers"],
     "_%n folder_::_%n folders_" : ["%n map","%n mappen"],
+    "Sort your bookmarks into folders, label them with tags and share them with others! The app will regularly check all your links for availability and display unavailable links. If you add a link to a file on the web, the file will be automatically downloaded to your Nextcloud Files. You can also import bookmarks exported from other services or directly sync bookmarks from all your browsers with this app." : "Sorteer je bladwijzers in mappen, label ze met tags en deel ze met anderen! De app controleert regelmatig al je links op beschikbaarheid en geeft niet-beschikbare links weer. Als je een link naar een bestand op internet toevoegt, wordt het bestand automatisch gedownload naar je Nextcloud-bestanden. Je kunt ook bladwijzers importeren die zijn geëxporteerd vanuit andere services of met deze app bladwijzers rechtstreeks synchroniseren vanuit al je browsers.",
     "Add a bookmark" : "Voeg een bladwijzer toe",
     "Import bookmarks" : "Importeer bladwijzers",
     "Sync with your browser" : "Sync met je browser",
@@ -109,6 +110,7 @@ OC.L10N.register(
     "Recent" : "Recent",
     "Shared with you" : "Gedeeld met jou",
     "Files" : "Bestanden",
+    "Duplicates" : "Duplicaten",
     "Broken links" : "Niet-werkende links",
     "New tag" : "Nieuwe tag",
     "Search tags" : "Zoek in tags",
@@ -116,6 +118,7 @@ OC.L10N.register(
     "{used} bookmarks of {available} available" : "{used} bladwijzers van {available} beschikbare",
     "No bookmarked files" : "Geen bladwijzers voor bestanden",
     "Bookmarks to files like photos or PDFs will automatically be saved to your Nextcloud files, so you can still find them even when the link goes offline." : "Bladwijzers naar bestanden zoals foto's of PDF's worden automatisch opgeslagen in je Nextcloud bestanden, zodat je ze nog steeds kunt vinden, zelfs als de link offline gaat.",
+    "No duplicated bookmarks" : "Geen duplicaat bladwijzers",
     "No bookmarks here" : "Geen bookmarks hier",
     "Import" : "Importeren",
     "Export" : "Exporteren",
@@ -130,6 +133,7 @@ OC.L10N.register(
     "Bookmarklet" : "Bookmarklet",
     "Drag this to your browser bookmarks and click it to quickly bookmark a webpage." : "Sleep dit naar je browser bladwijzers en open het om snel een bladwijzer van een website te maken.",
     "Add to {instanceName}" : "Toevoegen aan {instanceName}",
+    "Backup path" : "Back-up pad",
     "Please select \"Add to home screen\" in your browser menu" : "Selecteer 'Voeg toe aan thuisscherm' in je browser menu",
     "Title" : "Titel",
     "Link" : "Link",
