@@ -9,15 +9,15 @@ OC.L10N.register(
     "Copy link" : "Скопіювати посилання",
     "Move" : "Перемістити",
     "Delete" : "Вилучити",
-    "Delete selection" : "Видалити виділення",
+    "Delete selection" : "Прибрати виділення",
     "Select all" : "Вибрати все",
     "Go back" : "Повернутися назад",
-    "Share folder" : "Спільний доступ до папки",
+    "Share folder" : "Спільний доступ до каталогу",
     "New" : "Створити",
-    "New folder" : "Нова тека",
+    "New folder" : "Новий каталог",
     "Add a bookmark" : "Додати закладку",
-    "Rename folder" : "Переіменувати теку",
-    "Delete folder" : "Вилучити теку",
+    "Rename folder" : "Перейменувати каталог",
+    "Delete folder" : "Вилучити каталог",
     "Submit" : "Гаразд",
     "Cancel" : "Скасувати",
     "Recent" : "Нещодавні",
@@ -41,7 +41,7 @@ OC.L10N.register(
     "Privacy" : "Конфіденційність",
     "Failed to save settings" : "Неможливо зберегти налаштування",
     "This URL is already bookmarked! Overwrite?" : "Цей URL вже є в закладках! Перезаписати?",
-    "Folder" : "Папка",
+    "Folder" : "Каталог",
     "Save" : "Зберегти"
 },
 "nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");
