@@ -1,5 +1,9 @@
 <?php
-
+/*
+ * Copyright (c) 2020. The Nextcloud Bookmarks contributors.
+ *
+ * This file is licensed under the Affero General Public License version 3 or later. See the COPYING file.
+ */
 
 namespace OCA\Bookmarks\Migration;
 
@@ -18,7 +22,9 @@ class DeduplicateSharedFoldersRepairStep implements IRepairStep {
 	}
 
 	/**
-	 * Returns the step's name
+	 * 	 * Returns the step's name
+	 *
+	 * @return string
 	 */
 	public function getName() {
 		return 'Deduplicate shared bookmark folders';
@@ -26,15 +32,14 @@ class DeduplicateSharedFoldersRepairStep implements IRepairStep {
 
 	/**
 	 * @param IOutput $output
+	 *
+	 * @return void
 	 */
 	public function run(IOutput $output) {
 		$qb = $this->db->getQueryBuilder();
 		$qb->select('p1.id')
 			->from('bookmarks_shared_folders', 'p1')
-			->leftJoin('p1', 'bookmarks_shared_folders', 'p2', $qb->expr()->andX(
-				$qb->expr()->eq('p1.folder_id', 'p2.folder_id'),
-				$qb->expr()->eq('p1.user_id', 'p2.user_id')
-			))
+			->leftJoin('p1', 'bookmarks_shared_folders', 'p2', 'p1.folder_id = p2.folder_id AND p1.user_id = p2.user_id')
 			->where($qb->expr()->lt('p2.id', 'p1.id'));
 		$duplicateSharedFolders = $qb->execute();
 		$i = 0;
